@@ -3,9 +3,9 @@ package com.sun.tools.jdeps.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "16.0.1+9-24" },
-            { "jdk", "16.0.1" },
-            { "release", "16.0.1" },
+            { "full", "17.0.12+7" },
+            { "jdk", "17.0.12" },
+            { "release", "17.0.12" },
         };
     }
 }
